Unrestricted File Upload is a major risk for applications, the may result in system takeover, file system overload,
client-side attacks, or defacement. This vulnerability can be caused by insecure file metadata validation, like HTTP
Multi-part fields or insecure content and size validation, like uploading unauthorized file formats.
